@@ -33,7 +33,7 @@ from autobahn.wamp.types import RegisterOptions, CallDetails
 from autobahn.wamp.exception import ApplicationError, TransportLost
 from autobahn.wamp.protocol import ApplicationSession
 from ._util import unpack_uint256, pack_uint256
-from zlmdb import time_ns
+from txaio import time_ns
 
 import cbor2
 import eth_keys
@@ -176,8 +176,8 @@ class PayingChannel(object):
 
 
 class SimpleSeller(object):
-    log = txaio.make_logger()
 
+    log = None
     KeySeries = None
 
     STATE_NONE = 0
@@ -203,6 +203,8 @@ class SimpleSeller(object):
         assert type(seller_key) == bytes and len(seller_key) == 32, 'seller delegate must be bytes[32], but got "{}"'.format(seller_key)
         assert provider_id is None or type(provider_id) == str, 'provider_id must be None or string, but got "{}"'.format(provider_id)
 
+        self.log = txaio.make_logger()
+
         # current seller state
         self._state = SimpleSeller.STATE_NONE
 
